@@ -32,8 +32,8 @@ def profile_search(search, remote_url='http://54.36.177.119:4450'):
         # Finding all the elements with the class name "ScCoreLink-sc-udwpw5-0 jswAtS tw-link" and
         # then getting the text of each element and the href attribute of each element.
         results = driver.find_elements(By.CLASS_NAME, value=replace_spaces("ScCoreLink-sc-udwpw5-0 jswAtS tw-link"))
-        usernames = [element.text for element in results]
-        urls = [element.get_attribute("href") for element in results]
+        usernames = [element.text for element in results if element.text not in ["Top Clip", "Last Stream", '']]
+        urls = [element.get_attribute("href") for element in results if  element.text not in ["Top Clip", "Last Stream", '']]
         
         # Getting the images of the profiles.
         images = driver.find_elements(By.CLASS_NAME, value=replace_spaces("InjectLayout-sc-588ddc-0 iDjrEF tw-image tw-image-avatar"))
@@ -53,7 +53,9 @@ def profile_search(search, remote_url='http://54.36.177.119:4450'):
         return usernames, urls, images, profiles_dict
     
     except Exception as e:
+        logging.error(e)
         logging.error(f"Search on twitch for {search} has failed")
         driver.quit()
 
-#print(profile_search("marouane"))
\ No newline at end of file
+
+#print(profile_search("marouane"))
